@@ -463,7 +463,7 @@ BaseModuleWidget *MainWindow::initDesktopModeModule()
     module->updateBigIcon();
     BaseModuleWidget *w = new BaseModuleWidget(module, m_fakerWidget);
     w->setTitle(tr("Choose a desktop mode"));
-    w->setDescribe(tr("You can switch modes by right clicking on the dock"));
+    w->setDescribe(tr("You can switch alignment by right clicking on the dock"));
     w->setFixedSize(WINDOW_SIZE);
     return w;
 }
