@@ -174,7 +174,7 @@ NormalModule::NormalModule(DWidget *parent)
     desktopBtn->setToolTip(tr("Desktop Mode"));
     m_buttonMap[desktopBtn] = ++moduleCount;
     m_titleMap[desktopBtn] = tr("Choose a desktop mode");
-    m_describeMap[desktopBtn] = tr("You can switch modes by right clicking on the dock");
+    m_describeMap[desktopBtn] = tr("You can switch alignment by right clicking on the dock");
     m_buttonGrp->addButton(desktopBtn);
     DesktopModeModule *desktopModeModule = new DesktopModeModule(this);
     desktopModeModule->setFirst(false);
